@@ -781,4 +781,4 @@ class Item:
         获取元素控件的显示范围截图。\n
         :return: 截图的base64形态
         """
-        return self.device.grab_image_to_base64(self.__x, self.__y, self.__width, self.__height, self.__rotation, self.__scale)
+        return self.device.grab_image_to_base64(self.__center_x_to_global, self.__center_y_to_global, self.__width, self.__height, self.__rotation, self.__scale)
